Method: Appium::Core::WebSocket#handle_message_data

Defined in:
lib/appium_lib_core/common/ws/websocket.rb

#handle_message_data(data) ⇒ Object

Fires when the socket receives a message. The message gas one data attribute and this method can handle the data. The data is either a String (for text frames) or an Array of byte-sized integers (for binary frames).

Default is just put a debug message and puts the result on standard out. In general, users should override this handler to handle messages from the peer.



136
137
138
139
# File 'lib/appium_lib_core/common/ws/websocket.rb', line 136

def handle_message_data(data)
  ::Appium::Logger.debug %W(#{self.class} :message #{data})
  $stdout << "#{data}\n"
end