Method: Appium::Core::WebSocket#ping
- Defined in:
- lib/appium_lib_core/common/ws/websocket.rb
#ping(message, &callback) ⇒ Object
Sends a ping frame with an optional message and fires the callback when a matching pong is received.
80 81 82 |
# File 'lib/appium_lib_core/common/ws/websocket.rb', line 80 def ping(, &callback) @client.ping , &callback end |