Method: Appium::Core::Windows::Device#start_recording_screen
- Defined in:
- lib/appium_lib_core/windows/device.rb
#start_recording_screen(remote_path: nil, user: nil, pass: nil, method: 'PUT', force_restart: nil, time_limit: nil, fps: nil, preset: nil, video_filter: nil, capture_clicks: nil, capture_cursor: nil, audio_input: nil) ⇒ String
Record the display in background while the automated test is running. This method requires FFMPEG (www.ffmpeg.org/download.html) to be installed and present in PATH. The resulting video uses H264 codec and is ready to be played by media players built-in into web browsers.
|
|
# File 'lib/appium_lib_core/windows/device.rb', line 22
|