Module: Appium::Core::Base::HasRemoteStatus Private

Includes:
_Bridge
Included in:
Driver
Defined in:
lib/appium_lib_core/common/base/remote_status.rb,
sig/lib/appium_lib_core/common/base/remote_status.rbs

This module is part of a private API. You should avoid using this module if possible, as it may be removed or be changed in the future.

Instance Method Summary collapse

Methods included from _Bridge

#bridge, #execute, #execute_async_script, #execute_script

Instance Method Details

#remote_statusObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Selenium binding has this ability only in Remote Binding, so this library has this method by own for safe.

Returns:

  • (Object)


25
26
27
# File 'lib/appium_lib_core/common/base/remote_status.rb', line 25

def remote_status
  bridge.status
end