Method: Appium::Core::Base::Bridge#send_command
- Defined in:
- lib/appium_lib_core/common/base/bridge.rb
#send_command(command_params) ⇒ Object
for selenium-webdriver compatibility in chrome browser session. This may be needed in selenium-webdriver 4.8 or over? (around the version) when a session starts browserName: ‘chrome’ for bridge. This method is not only for Android, but also chrome desktop browser as well. So this bridge itself does not restrict the target module.
319 320 321 |
# File 'lib/appium_lib_core/common/base/bridge.rb', line 319 def send_command(command_params) execute :chrome_send_command, {}, command_params end |