Method: Appium::Core::Driver.attach_to
- Defined in:
- lib/appium_lib_core/driver.rb
.attach_to(session_id, url: nil, automation_name: nil, platform_name: nil, http_client_ops: { http_client: nil, open_timeout: 999_999, read_timeout: 999_999 }) ⇒ Selenium::WebDriver
Attach to an existing session. The main usage of this method is to attach to an existing session for debugging. The generated driver instance has the capabilities which has the given automationName and platformName only since the W3C WebDriver spec does not provide an endpoint to get running session’s capabilities.
307 308 309 310 311 312 313 314 315 316 317 318 |
# File 'lib/appium_lib_core/driver.rb', line 307 def self.attach_to( session_id, url: nil, automation_name: nil, platform_name: nil, http_client_ops: { http_client: nil, open_timeout: 999_999, read_timeout: 999_999 } ) new.attach_to( session_id, automation_name: automation_name, platform_name: platform_name, url: url, http_client_ops: http_client_ops ) end |