Method: Appium::Core::WebSocket#handle_error
- Defined in:
- lib/appium_lib_core/common/ws/websocket.rb
#handle_error ⇒ Object
Fires when there is a protocol error due to bad data sent by the other peer. This event is purely informational, you do not need to implement error recovery.
Default is just put a error message.
147 148 149 |
# File 'lib/appium_lib_core/common/ws/websocket.rb', line 147 def handle_error ::Appium::Logger.error %W(#{self.class} :error) end |