Method: Appium::Core::WebSocket#send
- Defined in:
- lib/appium_lib_core/common/ws/websocket.rb
#send(message) ⇒ Object
Accepts either a String or an Array of byte-sized integers and sends a text or binary message over the connection to the other peer; binary data must be encoded as an Array.
93 94 95 |
# File 'lib/appium_lib_core/common/ws/websocket.rb', line 93 def send() @client.send end |