Class: Appium::Core::Base::Bridge

Inherits:
Selenium::WebDriver::Remote::Bridge
  • Object
show all
Includes:
Device::AppManagement, Device::AppState, Device::Context, Device::Device, Device::DeviceLock, Device::ExecuteDriver, Device::FileManagement, Device::ImageComparison, Device::ImeActions, Device::KeyEvent, Device::Keyboard, Device::Orientation, Device::ScreenRecord::Command, Device::Setting
Defined in:
lib/appium_lib_core/common/base/bridge.rb

Constant Summary collapse

APPIUM_PREFIX =

Prefix for extra capability defined by W3C

'appium:'
APPIUM_NATIVE_BROWSER_NAME =

No ‘browserName’ means the session is native appium connection

'appium'

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#available_commandsObject (readonly)

Returns the value of attribute available_commands.



40
41
42
# File 'lib/appium_lib_core/common/base/bridge.rb', line 40

def available_commands
  @available_commands
end

Instance Method Details

#action(_deprecated_async = nil, async: false, devices: nil) ⇒ Object

Perform ‘touch’ actions for W3C module. Generate touch pointer action here and users can use this via driver.action

The pointer type is ‘touch’ by default in the Appium Ruby client.

Examples:


element = @driver.find_element(:id, "some id")
@driver.action.click(element).perform # The 'click' is a part of 'PointerActions'


189
190
191
192
193
194
195
196
# File 'lib/appium_lib_core/common/base/bridge.rb', line 189

def action(_deprecated_async = nil, async: false, devices: nil)
  ::Selenium::WebDriver::ActionBuilder.new(
    self,
    devices: devices || [::Selenium::WebDriver::Interactions.pointer(:touch, name: 'touch')],
    async: async,
    duration: 50 # milliseconds
  )
end

#active_elementObject Also known as: switch_to_active_element

For Appium override



223
224
225
# File 'lib/appium_lib_core/common/base/bridge.rb', line 223

def active_element
  ::Appium::Core::Element.new self, element_id_from(execute(:get_active_element))
end

#add_appium_prefix(capabilities) ⇒ ::Appium::Core::Base::Capabilities

Append appium: prefix for Appium following W3C spec www.w3.org/TR/webdriver/#dfn-validate-capabilities

Parameters:

Returns:



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/appium_lib_core/common/base/bridge.rb', line 118

def add_appium_prefix(capabilities)
  w3c_capabilities = ::Appium::Core::Base::Capabilities.new

  capabilities = capabilities.send(:capabilities) unless capabilities.is_a?(Hash)

  capabilities.each do |name, value|
    next if value.nil?
    next if value.is_a?(String) && value.empty?

    capability_name = name.to_s
    w3c_name = extension_prefix?(capability_name) ? name : "#{APPIUM_PREFIX}#{capability_name}"

    w3c_capabilities[w3c_name] = value
  end

  w3c_capabilities
end

#add_command(method:, url:, name:, &block) ⇒ Object

command for Appium 2.0.



159
160
161
162
163
164
165
# File 'lib/appium_lib_core/common/base/bridge.rb', line 159

def add_command(method:, url:, name:, &block)
  ::Appium::Logger.info "Overriding the method '#{name}' for '#{url}'" if @available_commands.key? name

  @available_commands[name] = [method, url]

  ::Appium::Core::Device.add_endpoint_method name, &block
end

#attach_to(session_id, platform_name, automation_name) ⇒ ::Appium::Core::Base::Capabilities

Appium only. Attach to an existing session.

Examples:


new_driver = ::Appium::Core::Driver.attach_to(
  driver.session_id,
  url: 'http://127.0.0.1:4723/wd/hub', automation_name: 'UiAutomator2', platform_name: 'Android'
)

Parameters:

  • The (String)

    session id to attach to.

  • platform_name (String)

    The platform name to keep in the dummy capabilities

  • platform_name (String)

    The automation name to keep in the dummy capabilities

Returns:



66
67
68
69
70
71
72
73
74
75
# File 'lib/appium_lib_core/common/base/bridge.rb', line 66

def attach_to(session_id, platform_name, automation_name)
  @available_commands = ::Appium::Core::Commands::COMMANDS.dup
  @session_id = session_id

  # generate a dummy capabilities instance which only has the given platformName and automationName
  @capabilities = ::Appium::Core::Base::Capabilities.new(
    'platformName' => platform_name,
    'automationName' => automation_name
  )
end

#available_log_typesObject

logs

For Appium No implementation for W3C webdriver module



311
312
313
314
# File 'lib/appium_lib_core/common/base/bridge.rb', line 311

def available_log_types
  types = execute :get_available_log_types
  Array(types).map(&:to_sym)
end

#browserObject



42
43
44
45
46
47
48
49
# File 'lib/appium_lib_core/common/base/bridge.rb', line 42

def browser
  @browser ||= begin
    name = @capabilities&.browser_name
    name ? name.tr(' ', '_').downcase.to_sym : 'unknown'
  rescue KeyError
    APPIUM_NATIVE_BROWSER_NAME
  end
end

#commands(command) ⇒ Object



167
168
169
# File 'lib/appium_lib_core/common/base/bridge.rb', line 167

def commands(command)
  @available_commands[command]
end

#convert_to_element(id) ⇒ ::Appium::Core::Element

For Appium

Parameters:

  • id (Hash)

    The id which can get as a response from server

Returns:



271
272
273
# File 'lib/appium_lib_core/common/base/bridge.rb', line 271

def convert_to_element(id)
  ::Appium::Core::Element.new self, element_id_from(id)
end

#create_session(capabilities) ⇒ ::Appium::Core::Base::Capabilities

Override Creates session handling.

Examples:


opts = {
  caps: {
    platformName: :ios,
    automationName: 'XCUITest',
    app: 'test/functional/app/UICatalog.app.zip',
    platformVersion: '11.4',
    deviceName: 'iPhone Simulator',
    useNewWDA: true,
  },
  appium_lib: {
    wait: 30
  }
}
core = ::Appium::Core.for(caps)
driver = core.start_driver

Parameters:

Returns:

Raises:

  • (::Selenium::WebDriver::Error::WebDriverError)


101
102
103
104
105
106
107
108
109
110
111
# File 'lib/appium_lib_core/common/base/bridge.rb', line 101

def create_session(capabilities)
  @available_commands = ::Appium::Core::Commands::COMMANDS.dup

  always_match = add_appium_prefix(capabilities)
  response = execute(:new_session, {}, { capabilities: { alwaysMatch: always_match, firstMatch: [{}] } })

  @session_id = response['sessionId']
  raise ::Selenium::WebDriver::Error::WebDriverError, 'no sessionId in returned payload' unless @session_id

  @capabilities = json_create(response['capabilities'])
end

#element_attribute(element, name) ⇒ Object

For Appium override



214
215
216
217
218
219
# File 'lib/appium_lib_core/common/base/bridge.rb', line 214

def element_attribute(element, name)
  # For W3C in Selenium Client
  # execute_atom :getAttribute, element, name.
  # 'dom_attribute' in the WebDriver Selenium.
  execute :get_element_attribute, id: element.id, name: name
end

#element_displayed?(element) ⇒ Boolean

For Appium override

Returns:

  • (Boolean)


205
206
207
208
209
210
# File 'lib/appium_lib_core/common/base/bridge.rb', line 205

def element_displayed?(element)
  # For W3C
  # https://github.com/SeleniumHQ/selenium/commit/b618499adcc3a9f667590652c5757c0caa703289
  # execute_atom :isDisplayed, element
  execute :is_element_displayed, id: element.id
end

#element_screenshot(element_id) ⇒ Object



345
346
347
# File 'lib/appium_lib_core/common/base/bridge.rb', line 345

def element_screenshot(element_id)
  execute :take_element_screenshot, id: element_id
end

#find_element_by(how, what, parent_ref = []) ⇒ Object

For Appium override



230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/appium_lib_core/common/base/bridge.rb', line 230

def find_element_by(how, what, parent_ref = [])
  how, what = convert_locator(how, what)

  return execute_atom(:findElements, Support::RelativeLocator.new(what).as_json).first if how == 'relative'

  parent_type, parent_id = parent_ref
  id = case parent_type
       when :element
         execute :find_child_element, { id: parent_id }, { using: how, value: what.to_s }
       when :shadow_root
         execute :find_shadow_child_element, { id: parent_id }, { using: how, value: what.to_s }
       else
         execute :find_element, {}, { using: how, value: what.to_s }
       end

  ::Appium::Core::Element.new self, element_id_from(id)
end

#find_elements_by(how, what, parent_ref = []) ⇒ Object

For Appium override



250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/appium_lib_core/common/base/bridge.rb', line 250

def find_elements_by(how, what, parent_ref = [])
  how, what = convert_locator(how, what)

  return execute_atom :findElements, Support::RelativeLocator.new(what).as_json if how == 'relative'

  parent_type, parent_id = parent_ref
  ids = case parent_type
        when :element
          execute :find_child_elements, { id: parent_id }, { using: how, value: what.to_s }
        when :shadow_root
          execute :find_shadow_child_elements, { id: parent_id }, { using: how, value: what.to_s }
        else
          execute :find_elements, {}, { using: how, value: what.to_s }
        end

  ids.map { |id| ::Appium::Core::Element.new self, element_id_from(id) }
end

#get_timeoutsObject

Port from MJSONWP



199
200
201
# File 'lib/appium_lib_core/common/base/bridge.rb', line 199

def get_timeouts
  execute :get_timeouts
end

#locationObject

For Appium No implementation for W3C webdriver module called in ‘extend DriverExtensions::HasLocation’



292
293
294
295
# File 'lib/appium_lib_core/common/base/bridge.rb', line 292

def location
  obj = execute(:get_location) || {}
  ::Appium::Location.new obj['latitude'], obj['longitude'], obj['altitude']
end

#log(type) ⇒ Object

For Appium No implementation for W3C webdriver module



318
319
320
321
322
323
324
325
326
# File 'lib/appium_lib_core/common/base/bridge.rb', line 318

def log(type)
  data = execute :get_log, {}, { type: type.to_s }

  Array(data).map do |l|
    ::Selenium::WebDriver::LogEntry.new l.fetch('level', 'UNKNOWN'), l.fetch('timestamp'), l.fetch('message')
  rescue KeyError
    next
  end
end

#log_event(vendor, event) ⇒ Object

For Appium



329
330
331
# File 'lib/appium_lib_core/common/base/bridge.rb', line 329

def log_event(vendor, event)
  execute :post_log_event, {}, { vendor: vendor, event: event }
end

#log_events(type = nil) ⇒ Object

For Appium



334
335
336
337
338
339
# File 'lib/appium_lib_core/common/base/bridge.rb', line 334

def log_events(type = nil)
  args = {}
  args['type'] = type unless type.nil?

  execute :get_log_events, {}, args
end

#network_connectionObject

For Appium override called in ‘extend DriverExtensions::HasNetworkConnection’



278
279
280
# File 'lib/appium_lib_core/common/base/bridge.rb', line 278

def network_connection
  execute :get_network_connection
end

#network_connection=(type) ⇒ Object

For Appium override called in ‘extend DriverExtensions::HasNetworkConnection’



285
286
287
# File 'lib/appium_lib_core/common/base/bridge.rb', line 285

def network_connection=(type)
  execute :set_network_connection, {}, { parameters: { type: type } }
end

#send_command(command_params) ⇒ Object

for selenium-webdriver compatibility in chrome browser session. This may be needed in selenium-webdriver 4.8 or over? (around the version) when a session starts browserName: ‘chrome’ for bridge. This method is not only for Android, but also chrome desktop browser as well. So this bridge itself does not restrict the target module.



354
355
356
# File 'lib/appium_lib_core/common/base/bridge.rb', line 354

def send_command(command_params)
  execute :chrome_send_command, {}, command_params
end

#set_location(lat, lon, alt = 0.0, speed: nil, satellites: nil) ⇒ Object

For Appium No implementation for W3C webdriver module



299
300
301
302
303
304
# File 'lib/appium_lib_core/common/base/bridge.rb', line 299

def set_location(lat, lon, alt = 0.0, speed: nil, satellites: nil)
  loc = { latitude: lat, longitude: lon, altitude: alt }
  loc[:speed] = speed unless speed.nil?
  loc[:satellites] = satellites unless satellites.nil?
  execute :set_location, {}, { location: loc }
end

#statusObject



171
172
173
# File 'lib/appium_lib_core/common/base/bridge.rb', line 171

def status
  execute :status
end

#viewport_screenshotObject



341
342
343
# File 'lib/appium_lib_core/common/base/bridge.rb', line 341

def viewport_screenshot
  execute_script('mobile: viewportScreenshot')
end