Class: Appium::Core::Base::Bridge

Inherits:
Selenium::WebDriver::Remote::Bridge
  • Object
show all
Includes:
Device::AppManagement, Device::AppState, Device::Context, Device::Device, Device::DeviceLock, Device::ExecuteDriver, Device::FileManagement, Device::ImageComparison, Device::ImeActions, Device::KeyEvent, Device::Keyboard, Device::Orientation, Device::ScreenRecord::Command, Device::Setting, Device::TouchActions, Device::Value
Defined in:
lib/appium_lib_core/common/base/bridge.rb

Constant Summary collapse

APPIUM_PREFIX =

Prefix for extra capability defined by W3C

'appium:'
APPIUM_NATIVE_BROWSER_NAME =

No 'browserName' means the session is native appium connection

'appium'

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#available_commandsObject (readonly)

Returns the value of attribute available_commands.



42
43
44
# File 'lib/appium_lib_core/common/base/bridge.rb', line 42

def available_commands
  @available_commands
end

Instance Method Details

#action(_deprecated_async = nil, async: false, devices: nil) ⇒ Object

Perform 'touch' actions for W3C module. Generate touch pointer action here and users can use this via driver.action

The pointer type is 'touch' by default in the Appium Ruby client.

Examples:


element = @driver.find_element(:id, "some id")
@driver.action.click(element).perform # The 'click' is a part of 'PointerActions'


195
196
197
198
199
200
201
202
# File 'lib/appium_lib_core/common/base/bridge.rb', line 195

def action(_deprecated_async = nil, async: false, devices: nil)
  ::Selenium::WebDriver::ActionBuilder.new(
    self,
    devices: devices || [::Selenium::WebDriver::Interactions.pointer(:touch, name: 'touch')],
    async: async,
    duration: 50 # milliseconds
  )
end

#active_elementObject Also known as: switch_to_active_element

For Appium override



238
239
240
# File 'lib/appium_lib_core/common/base/bridge.rb', line 238

def active_element
  ::Appium::Core::Element.new self, element_id_from(execute(:get_active_element))
end

#add_appium_prefix(capabilities) ⇒ ::Appium::Core::Base::Capabilities

Append appium: prefix for Appium following W3C spec www.w3.org/TR/webdriver/#dfn-validate-capabilities

Parameters:

Returns:



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/appium_lib_core/common/base/bridge.rb', line 120

def add_appium_prefix(capabilities)
  w3c_capabilities = ::Appium::Core::Base::Capabilities.new

  capabilities = capabilities.send(:capabilities) unless capabilities.is_a?(Hash)

  capabilities.each do |name, value|
    next if value.nil?
    next if value.is_a?(String) && value.empty?

    capability_name = name.to_s
    w3c_name = extension_prefix?(capability_name) ? name : "#{APPIUM_PREFIX}#{capability_name}"

    w3c_capabilities[w3c_name] = value
  end

  w3c_capabilities
end

#add_command(method:, url:, name:, &block) ⇒ Object

command for Appium 2.0.



161
162
163
164
165
166
167
# File 'lib/appium_lib_core/common/base/bridge.rb', line 161

def add_command(method:, url:, name:, &block)
  ::Appium::Logger.info "Overriding the method '#{name}' for '#{url}'" if @available_commands.key? name

  @available_commands[name] = [method, url]

  ::Appium::Core::Device.add_endpoint_method name, &block
end

#attach_to(session_id, platform_name, automation_name) ⇒ ::Appium::Core::Base::Capabilities

Appium only. Attach to an existing session.

Examples:


new_driver = ::Appium::Core::Driver.attach_to(
  driver.session_id,
  url: 'http://127.0.0.1:4723/wd/hub', automation_name: 'UiAutomator2', platform_name: 'Android'
)

Parameters:

  • The (String)

    session id to attach to.

  • platform_name (String)

    The platform name to keep in the dummy capabilities

  • platform_name (String)

    The automation name to keep in the dummy capabilities

Returns:



68
69
70
71
72
73
74
75
76
77
# File 'lib/appium_lib_core/common/base/bridge.rb', line 68

def attach_to(session_id, platform_name, automation_name)
  @available_commands = ::Appium::Core::Commands::COMMANDS.dup
  @session_id = session_id

  # generate a dummy capabilities instance which only has the given platformName and automationName
  @capabilities = ::Appium::Core::Base::Capabilities.new(
    'platformName' => platform_name,
    'automationName' => automation_name
  )
end

#available_log_typesObject

logs

For Appium No implementation for W3C webdriver module



326
327
328
329
# File 'lib/appium_lib_core/common/base/bridge.rb', line 326

def available_log_types
  types = execute :get_available_log_types
  Array(types).map(&:to_sym)
end

#browserObject



44
45
46
47
48
49
50
51
# File 'lib/appium_lib_core/common/base/bridge.rb', line 44

def browser
  @browser ||= begin
    name = @capabilities&.browser_name
    name ? name.tr(' ', '_').downcase.to_sym : 'unknown'
  rescue KeyError
    APPIUM_NATIVE_BROWSER_NAME
  end
end

#commands(command) ⇒ Object



169
170
171
# File 'lib/appium_lib_core/common/base/bridge.rb', line 169

def commands(command)
  @available_commands[command]
end

#convert_to_element(id) ⇒ ::Appium::Core::Element

For Appium

Parameters:

  • id (Hash)

    The id which can get as a response from server

Returns:



286
287
288
# File 'lib/appium_lib_core/common/base/bridge.rb', line 286

def convert_to_element(id)
  ::Appium::Core::Element.new self, element_id_from(id)
end

#create_session(capabilities) ⇒ ::Appium::Core::Base::Capabilities

Override Creates session handling.

Examples:


opts = {
  caps: {
    platformName: :ios,
    automationName: 'XCUITest',
    app: 'test/functional/app/UICatalog.app.zip',
    platformVersion: '11.4',
    deviceName: 'iPhone Simulator',
    useNewWDA: true,
  },
  appium_lib: {
    wait: 30
  }
}
core = ::Appium::Core.for(caps)
driver = core.start_driver

Parameters:

Returns:

Raises:

  • (::Selenium::WebDriver::Error::WebDriverError)


103
104
105
106
107
108
109
110
111
112
113
# File 'lib/appium_lib_core/common/base/bridge.rb', line 103

def create_session(capabilities)
  @available_commands = ::Appium::Core::Commands::COMMANDS.dup

  always_match = add_appium_prefix(capabilities)
  response = execute(:new_session, {}, { capabilities: { alwaysMatch: always_match, firstMatch: [{}] } })

  @session_id = response['sessionId']
  raise ::Selenium::WebDriver::Error::WebDriverError, 'no sessionId in returned payload' unless @session_id

  @capabilities = json_create(response['capabilities'])
end

#element_attribute(element, name) ⇒ Object

For Appium override



230
231
232
233
234
# File 'lib/appium_lib_core/common/base/bridge.rb', line 230

def element_attribute(element, name)
  # For W3C in Selenium Client
  # execute_atom :getAttribute, element, name
  execute :get_element_attribute, id: element.id, name: name
end

#element_displayed?(element) ⇒ Boolean

For Appium override

Returns:

  • (Boolean)


221
222
223
224
225
226
# File 'lib/appium_lib_core/common/base/bridge.rb', line 221

def element_displayed?(element)
  # For W3C
  # https://github.com/SeleniumHQ/selenium/commit/b618499adcc3a9f667590652c5757c0caa703289
  # execute_atom :isDisplayed, element
  execute :is_element_displayed, id: element.id
end

#element_screenshot(element_id) ⇒ Object



360
361
362
# File 'lib/appium_lib_core/common/base/bridge.rb', line 360

def element_screenshot(element_id)
  execute :take_element_screenshot, id: element_id
end

#find_element_by(how, what, parent_ref = []) ⇒ Object

For Appium override



245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/appium_lib_core/common/base/bridge.rb', line 245

def find_element_by(how, what, parent_ref = [])
  how, what = convert_locator(how, what)

  return execute_atom(:findElements, Support::RelativeLocator.new(what).as_json).first if how == 'relative'

  parent_type, parent_id = parent_ref
  id = case parent_type
       when :element
         execute :find_child_element, { id: parent_id }, { using: how, value: what.to_s }
       when :shadow_root
         execute :find_shadow_child_element, { id: parent_id }, { using: how, value: what.to_s }
       else
         execute :find_element, {}, { using: how, value: what.to_s }
       end

  ::Appium::Core::Element.new self, element_id_from(id)
end

#find_elements_by(how, what, parent_ref = []) ⇒ Object

For Appium override



265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/appium_lib_core/common/base/bridge.rb', line 265

def find_elements_by(how, what, parent_ref = [])
  how, what = convert_locator(how, what)

  return execute_atom :findElements, Support::RelativeLocator.new(what).as_json if how == 'relative'

  parent_type, parent_id = parent_ref
  ids = case parent_type
        when :element
          execute :find_child_elements, { id: parent_id }, { using: how, value: what.to_s }
        when :shadow_root
          execute :find_shadow_child_elements, { id: parent_id }, { using: how, value: what.to_s }
        else
          execute :find_elements, {}, { using: how, value: what.to_s }
        end

  ids.map { |id| ::Appium::Core::Element.new self, element_id_from(id) }
end

#get_timeoutsObject

Port from MJSONWP



205
206
207
# File 'lib/appium_lib_core/common/base/bridge.rb', line 205

def get_timeouts
  execute :get_timeouts
end

#locationObject

For Appium No implementation for W3C webdriver module called in 'extend DriverExtensions::HasLocation'



307
308
309
310
# File 'lib/appium_lib_core/common/base/bridge.rb', line 307

def location
  obj = execute(:get_location) || {}
  ::Selenium::WebDriver::Location.new obj['latitude'], obj['longitude'], obj['altitude']
end

#log(type) ⇒ Object

For Appium No implementation for W3C webdriver module



333
334
335
336
337
338
339
340
341
# File 'lib/appium_lib_core/common/base/bridge.rb', line 333

def log(type)
  data = execute :get_log, {}, { type: type.to_s }

  Array(data).map do |l|
    ::Selenium::WebDriver::LogEntry.new l.fetch('level', 'UNKNOWN'), l.fetch('timestamp'), l.fetch('message')
  rescue KeyError
    next
  end
end

#log_event(vendor, event) ⇒ Object

For Appium



344
345
346
# File 'lib/appium_lib_core/common/base/bridge.rb', line 344

def log_event(vendor, event)
  execute :post_log_event, {}, { vendor: vendor, event: event }
end

#log_events(type = nil) ⇒ Object

For Appium



349
350
351
352
353
354
# File 'lib/appium_lib_core/common/base/bridge.rb', line 349

def log_events(type = nil)
  args = {}
  args['type'] = type unless type.nil?

  execute :get_log_events, {}, args
end

#network_connectionObject

For Appium override called in 'extend DriverExtensions::HasNetworkConnection'



293
294
295
# File 'lib/appium_lib_core/common/base/bridge.rb', line 293

def network_connection
  execute :get_network_connection
end

#network_connection=(type) ⇒ Object

For Appium override called in 'extend DriverExtensions::HasNetworkConnection'



300
301
302
# File 'lib/appium_lib_core/common/base/bridge.rb', line 300

def network_connection=(type)
  execute :set_network_connection, {}, { parameters: { type: type } }
end

#page_sourceObject

Override for safe. Newer ruby selenium webdriver already has the same code



215
216
217
# File 'lib/appium_lib_core/common/base/bridge.rb', line 215

def page_source
  execute :get_page_source
end

#session_capabilitiesObject

Port from MJSONWP



210
211
212
# File 'lib/appium_lib_core/common/base/bridge.rb', line 210

def session_capabilities
  ::Appium::Core::Base::Capabilities.json_create execute(:get_capabilities)
end

#sessionsObject

Returns all available sessions on the Appium server instance



174
175
176
# File 'lib/appium_lib_core/common/base/bridge.rb', line 174

def sessions
  execute :get_all_sessions
end

#set_location(lat, lon, alt = 0.0, speed: nil, satellites: nil) ⇒ Object

For Appium No implementation for W3C webdriver module



314
315
316
317
318
319
# File 'lib/appium_lib_core/common/base/bridge.rb', line 314

def set_location(lat, lon, alt = 0.0, speed: nil, satellites: nil)
  loc = { latitude: lat, longitude: lon, altitude: alt }
  loc[:speed] = speed unless speed.nil?
  loc[:satellites] = satellites unless satellites.nil?
  execute :set_location, {}, { location: loc }
end

#statusObject



178
179
180
# File 'lib/appium_lib_core/common/base/bridge.rb', line 178

def status
  execute :status
end

#viewport_screenshotObject



356
357
358
# File 'lib/appium_lib_core/common/base/bridge.rb', line 356

def viewport_screenshot
  execute_script('mobile: viewportScreenshot')
end